@@ -162,6 +162,16 @@ CONST_KUBE_DASHBOARD_ADDON_NAME = "kubeDashboard"
 # azure policy
 CONST_AZURE_POLICY_ADDON_NAME = "azurepolicy"
 
+# Managed Namespace
+CONST_NAMESPACE_ADOPTION_POLICY_NEVER = "Never"
+CONST_NAMESPACE_ADOPTION_POLICY_IFIDENTICAL = "IfIdentical"
+CONST_NAMESPACE_ADOPTION_POLICY_ALWAYS = "Always"
+CONST_NAMESPACE_NETWORK_POLICY_RULE_DENYALL = "DenyAll"
+CONST_NAMESPACE_NETWORK_POLICY_RULE_ALLOWALL = "AllowAll"
+CONST_NAMESPACE_NETWORK_POLICY_RULE_ALLOWSAMENAMESPACE = "AllowSameNamespace"
+CONST_NAMESPACE_DELETE_POLICY_KEEP = "Keep"
+CONST_NAMESPACE_DELETE_POLICY_DELETE = "Delete"
+
 # ingress application gateway
 CONST_INGRESS_APPGW_ADDON_NAME = "ingressApplicationGateway"
 CONST_INGRESS_APPGW_APPLICATION_GATEWAY_NAME = "applicationGatewayName"
@@ -234,6 +244,8 @@ CONST_AZURE_SERVICE_MESH_INGRESS_MODE_INTERNAL = "Internal"
 CONST_AZURE_SERVICE_MESH_UPGRADE_COMMAND_START = "Start"
 CONST_AZURE_SERVICE_MESH_UPGRADE_COMMAND_COMPLETE = "Complete"
 CONST_AZURE_SERVICE_MESH_UPGRADE_COMMAND_ROLLBACK = "Rollback"
+CONST_AZURE_SERVICE_MESH_DEFAULT_EGRESS_NAMESPACE = "aks-istio-egress"
+CONST_AZURE_SERVICE_MESH_MAX_EGRESS_NAME_LENGTH = 63
 
 # Dns zone contributor role
 CONST_PRIVATE_DNS_ZONE_CONTRIBUTOR_ROLE = "Private DNS Zone Contributor"
@@ -251,6 +263,9 @@ CONST_NODE_PROVISIONING_MODE_AUTO = "Auto"
 CONST_NODE_PROVISIONING_DEFAULT_POOLS_NONE = "None"
 CONST_NODE_PROVISIONING_DEFAULT_POOLS_AUTO = "Auto"
 
+# consts for workloadruntime
+CONST_WORKLOAD_RUNTIME_KATA_VM_ISOLATION = "KataVmIsolation"
+
 
 # consts for decorator pattern
 class DecoratorMode(Enum):
