@@ -30,8 +30,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
 
     server_completers = {
         'mariadb': get_resource_name_completion_list('Microsoft.DBforMariaDB/servers'),
-        'mysql': get_resource_name_completion_list('Microsoft.DBforMySQL/servers'),
-        'postgres': get_resource_name_completion_list('Microsoft.DBforPostgreSQL/servers')
+        'mysql': get_resource_name_completion_list('Microsoft.DBforMySQL/servers')
     }
 
     def _complex_params(command_group):  # pylint: disable=too-many-statements
@@ -93,11 +92,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
             c.argument('assign_identity', options_list=['--assign-identity'], help='Generate and assign an Microsoft Entra Identity for this server for use with key management services like Azure KeyVault.')
 
             c.argument('location', arg_type=get_location_type(self.cli_ctx))
-            if command_group == 'postgres':
-                c.argument('version', default='11',
-                           help='Server major version. https://learn.microsoft.com/en-us/azure/postgresql/single-server/concepts-supported-versions')
-            else:
-                c.argument('version', help='Server major version.')
+            c.argument('version', help='Server major version.')
 
         with self.argument_context('{} server update'.format(command_group)) as c:
             c.ignore('family', 'capacity', 'tier')
@@ -220,7 +215,6 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
 
     _complex_params('mariadb')
     _complex_params('mysql')
-    _complex_params('postgres')
 
     # Flexible-server
     # pylint: disable=too-many-locals, too-many-branches
@@ -340,12 +334,6 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
                  'This value can only be updated if flexible server is using Premium SSD v2 Disks.'
         )
 
-        create_default_db_arg_type = CLIArgumentType(
-            arg_type=get_enum_type(['Enabled', 'Disabled']),
-            options_list=['--create-default-database', '-c'],
-            help='Enable or disable the creation of default database flexibleserverdb. Default value is Disabled.'
-        )
-
         cluster_option_arg_type = CLIArgumentType(
             arg_type=get_enum_type(['Server', 'ElasticCluster']),
             options_list=['--cluster-option'],
@@ -604,7 +592,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
                 c.argument('tier', default='GeneralPurpose', arg_type=tier_arg_type)
                 c.argument('sku_name', arg_type=sku_name_arg_type)
                 c.argument('storage_gb', default='128', arg_type=storage_gb_arg_type)
-                c.argument('version', default='17', arg_type=version_arg_type)
+                c.argument('version', arg_type=version_arg_type)
                 c.argument('backup_retention', default=7, arg_type=pg_backup_retention_arg_type)
                 c.argument('microsoft_entra_auth', default='Disabled', arg_type=microsoft_entra_auth_arg_type)
                 c.argument('admin_id', options_list=['--admin-object-id', '-i'], help='The unique ID of the Microsoft Entra administrator.')
@@ -617,7 +605,6 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
                 c.argument('iops', default=None, arg_type=iops_v2_arg_type)
                 c.argument('throughput', default=None, arg_type=throughput_arg_type)
                 c.argument('performance_tier', default=None, arg_type=performance_tier_arg_type)
-                c.argument('create_default_db', default='Disabled', arg_type=create_default_db_arg_type)
                 c.argument('create_cluster', default='Server', arg_type=cluster_option_arg_type)
                 c.argument('cluster_size', default=None, arg_type=create_node_count_arg_type)
             elif command_group == 'mysql':
@@ -647,7 +634,6 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
             c.argument('zone', zone_arg_type)
             c.argument('tags', tags_type)
             c.argument('standby_availability_zone', arg_type=standby_availability_zone_arg_type)
-            c.argument('database_name', arg_type=database_name_create_arg_type)
             c.argument('yes', arg_type=yes_arg_type)
 
         with self.argument_context('{} flexible-server list'.format(command_group)) as c:
