@@ -75,6 +75,7 @@ DEFAULT_BACKEND_PORT = 3389
 SERVICE_FABRIC_WINDOWS_NODE_EXT_NAME = "servicefabricnode"
 SERVICE_FABRIC_LINUX_NODE_EXT_NAME = "servicefabriclinuxnode"
 
+CLUSTER_NAME_VALUE = "clusterName"
 SOURCE_VAULT_VALUE = "sourceVaultValue"
 CERTIFICATE_THUMBPRINT = "certificateThumbprint"
 CERTIFICATE_URL_VALUE = "certificateUrlValue"
@@ -145,7 +146,7 @@ def new_cluster(cmd,
                 'when \'--secret-identifier\' is specified')
     if parameter_file or template_file:
         if parameter_file is None or template_file is None:
-            raise CLIError('If using customize template to deploy,both \'--parameter-file\' and \'--template-file\' can not be None ' + '\n For example:\n az sf cluster create --resource-group myRg --location westus --certificate-subject-name test.com --parameter-file c:\\parameter.json --template-file c:\\template.json' +
+            raise CLIError('If using customize template to deploy, neither \'--parameter-file\' and \'--template-file\' can be None ' + '\n For example:\n az sf cluster create --resource-group myRg --location westus --certificate-subject-name test.com --parameter-file c:\\parameter.json --template-file c:\\template.json' +
                            '\n az sf cluster create --resource-group myRg --location westus --parameter-file c:\\parameter.json --template-file c:\\template.json --certificate_file c:\\test.pfx' + '\n az sf cluster create --resource-group myRg --location westus --certificate-subject-name test.com --parameter-file c:\\parameter.json --template-file c:\\template.json --certificate-output-folder c:\\certoutput')
         if cluster_size or vm_sku or vm_user_name:
             raise CLIError('\'cluster_size\',\'vm_sku\',\'vm_os\',\'vm_user_name\' can not be specified when using customize template deployment')
@@ -204,7 +205,8 @@ def new_cluster(cmd,
                                      vault_resource_group_name,
                                      certificate_output_folder,
                                      certificate_subject_name,
-                                     secret_identifier)
+                                     secret_identifier,
+                                     location)
         vault_id = result[0]
         certificate_uri = result[1]
         cert_thumbprint = result[2]
@@ -229,18 +231,19 @@ def new_cluster(cmd,
                                                           os_type=vm_os,
                                                           linux=linux)
     else:
-        parameters, output_file = _set_parameters_for_customize_template(cmd,
-                                                                         cli_ctx,
-                                                                         resource_group_name,
-                                                                         certificate_file,
-                                                                         certificate_password,
-                                                                         vault_name,
-                                                                         vault_resource_group_name,
-                                                                         certificate_output_folder,
-                                                                         certificate_subject_name,
-                                                                         secret_identifier,
-                                                                         parameter_file)
+        parameters, output_file = _set_parameters_for_customize_template(cmd=cmd,
+                                                                         cli_ctx=cli_ctx,
+                                                                         resource_group_name=resource_group_name,
+                                                                         certificate_file=certificate_file,
+                                                                         certificate_password=certificate_password,
+                                                                         vault_name=vault_name,
+                                                                         vault_resource_group_name=vault_resource_group_name,
+                                                                         certificate_output_folder=certificate_output_folder,
+                                                                         certificate_subject_name=certificate_subject_name,
+                                                                         secret_identifier=secret_identifier,
+                                                                         parameter_file=parameter_file)
 
+        cluster_name = parameters[CLUSTER_NAME_VALUE]['value']
         vault_id = parameters[SOURCE_VAULT_VALUE]['value']
         certificate_uri = parameters[CERTIFICATE_URL_VALUE]['value']
         cert_thumbprint = parameters[CERTIFICATE_THUMBPRINT]['value']
@@ -284,6 +287,8 @@ def add_app_cert(cmd,
                  certificate_subject_name=None,
                  secret_identifier=None):
     cli_ctx = cmd.cli_ctx
+    cluster = client.get(resource_group_name, cluster_name)
+    location = cluster.location
     result = _create_certificate(cmd,
                                  cli_ctx,
                                  resource_group_name,
@@ -293,7 +298,8 @@ def add_app_cert(cmd,
                                  vault_resource_group_name,
                                  certificate_output_folder,
                                  certificate_subject_name,
-                                 secret_identifier)
+                                 secret_identifier,
+                                 location)
 
     _add_cert_to_all_vmss(cli_ctx, resource_group_name, None, result[0], result[1])
     return client.get(resource_group_name, cluster_name)
@@ -1072,7 +1078,8 @@ def _create_certificate(cmd,
                         vault_resource_group_name=None,
                         certificate_output_folder=None,
                         certificate_subject_name=None,
-                        secret_identifier=None):
+                        secret_identifier=None,
+                        location=None):
     _verify_cert_function_parameter(certificate_file, certificate_password,
                                     vault_name, vault_resource_group_name,
                                     certificate_output_folder,
@@ -1080,9 +1087,8 @@ def _create_certificate(cmd,
                                     secret_identifier)
 
     output_file = None
-    rg = _get_resource_group_by_name(cli_ctx, resource_group_name)
-    location = rg.location
-
+    if location is None:
+        location = _get_resource_group_by_name(cli_ctx, resource_group_name).location
     vault_id = None
     secret_url = None
     certificate_thumbprint = None
@@ -1778,6 +1784,9 @@ def _set_parameters_for_customize_template(cmd,
     parameters = get_file_json(parameter_file)['parameters']
     if parameters is None:
         raise CLIError('Invalid parameters file')
+
+    location = parameters['clusterLocation']['value']
+
     if SOURCE_VAULT_VALUE in parameters and CERTIFICATE_THUMBPRINT in parameters and CERTIFICATE_URL_VALUE in parameters:
         logger.info('Found primary certificate parameters in parameters file')
         result = _create_certificate(cmd,
@@ -1789,7 +1798,8 @@ def _set_parameters_for_customize_template(cmd,
                                      vault_resource_group_name,
                                      certificate_output_folder,
                                      certificate_subject_name,
-                                     secret_identifier)
+                                     secret_identifier,
+                                     location)
         parameters[SOURCE_VAULT_VALUE]['value'] = result[0]
         parameters[CERTIFICATE_URL_VALUE]['value'] = result[1]
         parameters[CERTIFICATE_THUMBPRINT]['value'] = result[2]
@@ -1810,7 +1820,8 @@ def _set_parameters_for_customize_template(cmd,
                                      vault_resource_group_name,
                                      certificate_output_folder,
                                      certificate_subject_name,
-                                     secret_identifier)
+                                     secret_identifier,
+                                     location)
         parameters[SOURCE_VAULT_VALUE]['value'] = result[0]
         parameters[CERTIFICATE_URL_VALUE]['value'] = result[1]
         parameters[CERTIFICATE_THUMBPRINT]['value'] = result[2]
