@@ -107,7 +107,7 @@ def load_command_table(self, _):  # pylint: disable=too-many-locals, too-many-st
                          'show_storage_account_connection_string')
         g.generic_update_command('update', getter_name='get_properties', setter_name='update',
                                  custom_func_name='update_storage_account')
-        g.custom_command('failover', 'begin_failover', supports_no_wait=True, is_preview=True)
+        g.custom_command('failover', 'begin_failover', supports_no_wait=True)
         g.command('hns-migration start', 'begin_hierarchical_namespace_migration',
                   supports_no_wait=True)
         g.command('hns-migration stop', 'begin_abort_hierarchical_namespace_migration',
@@ -213,7 +213,7 @@ def load_command_table(self, _):  # pylint: disable=too-many-locals, too-many-st
         operations_tmpl='azure.cli.command_modules.storage.operations.account#{}',
         client_factory=cf_or_policy)
 
-    with self.command_group('storage account or-policy', or_policy_sdk, is_preview=True,
+    with self.command_group('storage account or-policy', or_policy_sdk,
                             resource_type=ResourceType.MGMT_STORAGE,
                             custom_command_type=or_policy_custom_type) as g:
         g.show_command('show', 'get')
@@ -222,7 +222,7 @@ def load_command_table(self, _):  # pylint: disable=too-many-locals, too-many-st
         g.generic_update_command('update', setter_name='update_or_policy', setter_type=or_policy_custom_type)
         g.command('delete', 'delete')
 
-    with self.command_group('storage account or-policy rule', or_policy_sdk, is_preview=True,
+    with self.command_group('storage account or-policy rule', or_policy_sdk,
                             resource_type=ResourceType.MGMT_STORAGE,
                             custom_command_type=or_policy_custom_type) as g:
         g.custom_show_command('show', 'get_or_rule')
@@ -699,6 +699,8 @@ def load_command_table(self, _):  # pylint: disable=too-many-locals, too-many-st
                                        transform=transform_file_show_result)
         g.storage_custom_command_oauth('download-batch', 'storage_file_download_batch', client_factory=cf_share_client)
         g.storage_command_oauth('hard-link create', 'create_hardlink')
+        g.storage_command_oauth('symbolic-link create', 'create_symlink')
+        g.storage_command_oauth('symbolic-link show', 'get_symlink')
 
     with self.command_group('storage cors', get_custom_sdk('cors', multi_service_properties_factory)) as g:
         from ._transformers import transform_cors_list_output
