@@ -95,11 +95,11 @@ def list_share_files(cmd, client, directory_name=None, timeout=None, exclude_dir
     from ..track2_util import list_generator
     include = None
     share_properties = client.get_share_properties()
-    if share_properties.protocols == ['SMB']:
-        include = [] if exclude_extended_info else ["timestamps", "Etag", "Attributes", "PermissionKey"]
-    elif share_properties.protocols == ['NFS']:
+    if share_properties.protocols == ['NFS']:
         if exclude_extended_info:
             logger.warning('--exclude-extended-info is not supported for NFS shares.')
+    else:
+        include = [] if exclude_extended_info else ["timestamps", "Etag", "Attributes", "PermissionKey"]
     generator = client.list_directories_and_files(directory_name=directory_name, include=include,
                                                   timeout=timeout, results_per_page=num_results)
     pages = generator.by_page(continuation_token=marker)
