@@ -9,7 +9,7 @@ import sys
 import warnings
 from io import BytesIO
 from itertools import islice
-from typing import AsyncIterator, Generic, Optional, TypeVar
+from typing import AsyncIterator, Generic, IO, Optional, TypeVar
 
 import asyncio
 
@@ -353,7 +353,7 @@ class StorageStreamDownloader(Generic[T]):  # pylint: disable=too-many-instance-
             # Parse the total file size and adjust the download size if ranges
             # were specified
             self._file_size = parse_length_from_content_range(response.properties.content_range)
-            if not self._file_size:
+            if self._file_size is None:
                 raise ValueError("Required Content-Range response header is missing or malformed.")
             # Remove any extra encryption data size from blob size
             self._file_size = adjust_blob_size_for_encryption(self._file_size, self._encryption_data)
@@ -367,7 +367,7 @@ class StorageStreamDownloader(Generic[T]):  # pylint: disable=too-many-instance-
                 self.size = self._file_size
 
         except HttpResponseError as error:
-            if self._start_range is None and error.status_code == 416:
+            if self._start_range is None and error.response and error.status_code == 416:
                 # Get range will fail on an empty file. If the user did not
                 # request a range, do a regular get request in order to get
                 # any properties.
@@ -461,10 +461,10 @@ class StorageStreamDownloader(Generic[T]):  # pylint: disable=too-many-instance-
         is unspecified or is -1, all bytes will be read.
 
         :param size:
-            The number of bytes to download from the stream. Leave unsepcified
+            The number of bytes to download from the stream. Leave unspecified
             or set to -1 to download all bytes.
         :returns:
-            The requsted data as bytes or a string if encoding was speicified. If
+            The requested data as bytes or a string if encoding was specified. If
             the return value is empty, there is no more data to read.
         :rtype: T
         """
@@ -552,13 +552,12 @@ class StorageStreamDownloader(Generic[T]):  # pylint: disable=too-many-instance-
             return data.decode(self._encoding)
         return data
 
-    async def readall(self):
-        # type: () -> T
+    async def readall(self) -> T:
         """
         Read the entire contents of this blob.
         This operation is blocking until all data is downloaded.
 
-        :returns: The requsted data as bytes or a string if encoding was speicified.
+        :returns: The requested data as bytes or a string if encoding was specified.
         :rtype: T
         """
         stream = BytesIO()
@@ -569,10 +568,12 @@ class StorageStreamDownloader(Generic[T]):  # pylint: disable=too-many-instance-
         return data
 
     async def content_as_bytes(self, max_concurrency=1):
-        """Download the contents of this file.
+        """DEPRECATED: Download the contents of this file.
 
         This operation is blocking until all data is downloaded.
 
+        This method is deprecated, use func:`readall` instead.
+
         :keyword int max_concurrency:
             The number of parallel connections with which to download.
         :rtype: bytes
@@ -585,10 +586,12 @@ class StorageStreamDownloader(Generic[T]):  # pylint: disable=too-many-instance-
         return await self.readall()
 
     async def content_as_text(self, max_concurrency=1, encoding="UTF-8"):
-        """Download the contents of this blob, and decode as text.
+        """DEPRECATED: Download the contents of this blob, and decode as text.
 
         This operation is blocking until all data is downloaded.
 
+        This method is deprecated, use func:`readall` instead.
+
         :param int max_concurrency:
             The number of parallel connections with which to download.
         :param str encoding:
@@ -603,7 +606,7 @@ class StorageStreamDownloader(Generic[T]):  # pylint: disable=too-many-instance-
         self._encoding = encoding
         return await self.readall()
 
-    async def readinto(self, stream):
+    async def readinto(self, stream: IO[T]) -> int:
         """Download the contents of this blob to a stream.
 
         :param stream:
@@ -699,7 +702,9 @@ class StorageStreamDownloader(Generic[T]):  # pylint: disable=too-many-instance-
         return remaining_size
 
     async def download_to_stream(self, stream, max_concurrency=1):
-        """Download the contents of this blob to a stream.
+        """DEPRECATED: Download the contents of this blob to a stream.
+
+        This method is deprecated, use func:`readinto` instead.
 
         :param stream:
             The stream to download to. This can be an open file-handle,
